@@ -1,12 +1,18 @@
 from gbmgeometry.gbm import GBM  # , get_legal_pairs
-from gbmgeometry.gbm_detector import BGO0, BGO1
-from gbmgeometry.gbm_detector import NaI0, NaI1, NaI2, NaI3, NaI4, NaI5
-from gbmgeometry.gbm_detector import NaI6, NaI7, NaI8, NaI9, NaIA, NaIB
+from gbmgeometry.gbm_detector import (BGO0, BGO1, NaI0, NaI1, NaI2, NaI3, NaI4,
+                                      NaI5, NaI6, NaI7, NaI8, NaI9, NaIA, NaIB)
 from gbmgeometry.gbm_frame import GBMFrame
+from gbmgeometry.io.data_download import (download_posthist, download_trigdat,
+                                          get_official_location)
 from gbmgeometry.position_interpolator import PositionInterpolator
 from gbmgeometry.spacecraft.fermi import Fermi
-from gbmgeometry.utils.file_converters import convert_poshist2hdf5, convert_trigdat2hdf5
-from gbmgeometry.utils.plotting.space_plot import plot_in_space, animate_in_space
+from gbmgeometry.utils.file_converters import (convert_poshist2hdf5,
+                                               convert_trigdat2hdf5)
+from gbmgeometry.utils.gbm_time import GBMTime
+from gbmgeometry.utils.plotting.space_plot import (animate_in_space,
+                                                   plot_in_space)
+
+from ._version import get_versions
 
 gbm_detector_list = {
     "n0": NaI0,
@@ -26,8 +32,6 @@ gbm_detector_list = {
 }
 
 
-from gbmgeometry.utils.gbm_time import GBMTime
-
 __all__ = [
     "plot_in_space",
     "animate_in_space",
@@ -56,7 +60,6 @@ __all__ = [
     "gbm_detector_list",
 ]
 
-from ._version import get_versions
 
 __version__ = get_versions()["version"]
 del get_versions
