@@ -1,5 +1,5 @@
 from astropy.coordinates.builtin_frames.utils import get_polar_motion, get_jd12
-from astropy import _erfa as erfa
+import erfa
 import numpy as np
 
 
