@@ -1,30 +1,42 @@
-import astropy.io.fits as fits
-import h5py
-import astropy.units as u
-from astropy.coordinates import get_sun, get_moon, get_body
-import astropy.time as astro_time
+import typing as tp
 
+import astropy.io.fits as fits
+import astropy.time as astro_time
+import astropy.units as u
+import h5py
 import numpy as np
 import scipy.interpolate as interpolate
+from astropy.coordinates import get_body, get_moon, get_sun
 
 from gbmgeometry.utils.gbm_time import GBMTime
 
 
 class PositionInterpolator(object):
-    def __init__(self, quats, sc_pos, time, trigtime=None, factor=1, flags=None):
-        """FIXME! briefly describe function
+    def __init__(self,
+                 quats: tp.Iterable[float],
+                 sc_pos: tp.Iterable[float],
+                 time: float,
+                 trigtime=None,
+                 factor=1,
+                 flags=None):
+        """
+        An object for interpolating the orbit of 
+        GBM
 
-        :param poshist: 
-        :param T0: 
-        :param trigdat: 
+        :param quaternions
+        :param sc_pos: 
+        :param time:
+        :param trigtime:
+        :param factor:
+        :param flags:
         :returns: 
         :rtype: 
 
         """
 
-        self._quats = quats
-        self._sc_pos = sc_pos
-        self._time = time
+        self._quats: tp.Iterable[float] = quats
+        self._sc_pos: tp.Iterable[float] = sc_pos
+        self._time: float = time
         self._trigtime = trigtime
         self._factor = factor
         self._flags = flags
@@ -35,7 +47,7 @@ class PositionInterpolator(object):
         self._interpolate_flags()
 
     @classmethod
-    def from_trigdat_hdf5(cls, trigdat_file):
+    def from_trigdat_hdf5(cls, trigdat_file: str):
         """
         create and interpolator from a trigdat
         HDF5 file
@@ -227,7 +239,7 @@ class PositionInterpolator(object):
         """
         Get the position of the sun at the give time
         relative to the geocenter
-        
+
 
         :param t: 
         :returns: 
@@ -241,7 +253,7 @@ class PositionInterpolator(object):
         """
         Get the position of the moon at the give time
         relative to the geocenter
-        
+
 
         :param t: 
         :returns: 
@@ -255,7 +267,7 @@ class PositionInterpolator(object):
         """
         Get the position of the body at the give time
         relative to the geocenter
-        
+
 
         :param t: 
         :param body:
@@ -303,7 +315,7 @@ class PositionInterpolator(object):
     def sc_pos(self, t):
         """
         the space craft postions in X,Y,Z geocentric coordinates
-        
+
         units are always assumed to be kilometers
 
         :param t: 
@@ -318,6 +330,48 @@ class PositionInterpolator(object):
         names = [f"sc_pos_{s}" for s in ["X", "Y", "Z"]]
         return dict(zip(names, self._scxyz_t(t) * self._factor))
 
+    def is_earth_occulted(self, ra, dec, t):
+
+        earth_radius = 6371.0
+
+        sc_pos = self.sc_pos(t)
+
+        if np.atleast_1d(t).shape[0] == 1:
+
+            fermi_radius = np.sqrt((sc_pos ** 2).sum())
+
+            horizon_angle = 90 - \
+                np.rad2deg(np.arccos(earth_radius / fermi_radius))
+
+            min_vis = np.deg2rad(horizon_angle)
+
+            cart_position = ang2cart(ra, dec)
+
+            ang_sep = get_ang(cart_position, -sc_pos)
+
+            return ang_sep < min_vis
+
+        else:
+
+            out = np.ones(len(t), dtype=bool)
+
+            for i, scp in enumerate(sc_pos):
+
+                fermi_radius = np.sqrt((scp ** 2).sum())
+
+                horizon_angle = 90 - \
+                    np.rad2deg(np.arccos(earth_radius / fermi_radius))
+
+                min_vis = np.deg2rad(horizon_angle)
+
+                cart_position = ang2cart(ra, dec)
+
+                ang_sep = get_ang(cart_position, -scp)
+
+                out[i] = ang_sep < min_vis
+
+            return out
+
     def _interpolate_quaternion(self):
 
         self._quaternion_t = interpolate.interp1d(self._time, self._quats.T)
@@ -402,7 +456,7 @@ class PositionInterpolator(object):
 
     def altitude(self, t):
         """
-        
+
         :param t: 
         :return: 
         """
@@ -418,6 +472,36 @@ class PositionInterpolator(object):
         return x / norm
 
 
+def ang2cart(ra, dec):
+    """
+    :param ra:
+    :param dec:
+    :return:
+    """
+    pos = np.zeros(3)
+    ra = np.deg2rad(ra)
+    dec = np.deg2rad(dec)
+
+    pos[0] = np.cos(dec) * np.cos(ra)
+    pos[1] = np.cos(dec) * np.sin(ra)
+    pos[2] = np.sin(dec)
+
+    return pos
+
+
+def get_ang(X1, X2):
+    """
+    :param X1:
+    :param X2:
+    :return:
+    """
+    norm1 = np.sqrt(X1.dot(X1))
+    norm2 = np.sqrt(X2.dot(X2))
+    tmp = np.clip(np.dot(X1 / norm1, X2 / norm2), -1, 1)
+
+    return np.arccos(tmp)
+
+
 def slice_disjoint(arr):
     """
     Returns an array of disjoint indices from a bool array
