@@ -1,8 +1,8 @@
-from gbmgeometry.spacecraft.geometry import Volume
+from gbmgeometry.geometry import Volume
 
 
 class LAT(Volume):
-    def __init__(self):
+    def __init__(self, transform_matrix=None, sc_pos=None, quaternion=None):
         # cm
 
         height = 106.0
@@ -22,13 +22,24 @@ class LAT(Volume):
             height=height,
             x_width=x_width,
             y_width=y_width,
+            transform_matrix=transform_matrix,
+            sc_pos=sc_pos,
+            quaternion=quaternion,
             color="#0000CE",
             active_surfaces=active_surfaces,
         )
 
 
 class LATRadiator(Volume):
-    def __init__(self, name, sign, active_surfaces):
+    def __init__(
+        self,
+        name,
+        sign,
+        active_surfaces,
+        transform_matrix=None,
+        sc_pos=None,
+        quaternion=None,
+    ):
         # cm
 
         height = 158.6
@@ -46,20 +57,37 @@ class LATRadiator(Volume):
             height=height,
             x_width=x_width,
             y_width=y_width,
+            transform_matrix=transform_matrix,
+            sc_pos=sc_pos,
+            quaternion=quaternion,
             color="darkgrey",
             active_surfaces=active_surfaces,
         )
 
 
 class LATRadiatorMinus(LATRadiator):
-    def __init__(self):
+    def __init__(self, transform_matrix=None, sc_pos=None, quaternion=None):
         active_surfaces = ["+x", "-x", "+y", "-z"]
 
-        super(LATRadiatorMinus, self).__init__("LAT Radiator-", -1, active_surfaces)
+        super(LATRadiatorMinus, self).__init__(
+            "LAT Radiator-",
+            -1,
+            active_surfaces,
+            transform_matrix=transform_matrix,
+            sc_pos=sc_pos,
+            quaternion=quaternion,
+        )
 
 
 class LATRadiatorPlus(LATRadiator):
-    def __init__(self):
+    def __init__(self, transform_matrix=None, sc_pos=None, quaternion=None):
         active_surfaces = ["+x", "-x", "-y", "-z"]
 
-        super(LATRadiatorPlus, self).__init__("LAT Radiator+", 1, active_surfaces)
+        super(LATRadiatorPlus, self).__init__(
+            "LAT Radiator+",
+            1,
+            active_surfaces,
+            transform_matrix=transform_matrix,
+            sc_pos=sc_pos,
+            quaternion=quaternion,
+        )
